@@ -240,19 +240,18 @@ class Beaker:
 
         This can improve performance when calling a series of a client methods in a row.
 
-        :param session: The session to use.
-            If not provided a default will be used.
-
-            .. warning::
-                Only set the ``session`` argument if you really know what you're doing! Otherwise
-                just leave this as ``None``.
-
         :examples:
 
         >>> with beaker.session():
         ...     n_images = len(beaker.workspace.images())
         ...     n_datasets = len(beaker.workspace.datasets())
 
+        :param session: The session to use. If not provided a default will be used.
+
+            .. warning::
+                Only set the ``session`` argument if you really know what you're doing! Otherwise
+                just leave this as ``None``.
+
         """
         current = self._session
         session = session or self._make_session()
@@ -332,8 +331,8 @@ class Beaker:
 
         :examples:
 
-        >>> beaker.cluster.get(beaker_cloud_cluster_name).autoscale
-        True
+        >>> beaker.cluster.get(beaker_cluster_name).name
+        'ai2/canary'
 
         .. tip::
             See the `Clusters Overview <overview.html#clusters>`_ for a walk-through of the
