@@ -1,9 +1,7 @@
 from datetime import datetime
 from typing import Optional, Tuple
 
-from pydantic import validator
-
-from .base import BaseModel, StrEnum
+from .base import BaseModel, StrEnum, field_validator
 from .node import NodeResources, NodeUtilization
 
 __all__ = ["ClusterStatus", "Cluster", "ClusterUtilization", "ClusterSpec", "ClusterPatch"]
@@ -41,14 +39,17 @@ class Cluster(BaseModel):
     node_cost: Optional[str] = None
     validated: Optional[datetime] = None
     user_restrictions: Optional[Tuple[str, ...]] = None
+    allow_preemptible_restriction_exceptions: Optional[bool] = None
+    compute_source: Optional[str] = None
+    max_job_timeout: Optional[int] = None
 
-    @validator("validated")
+    @field_validator("validated")
     def _validate_datetime(cls, v: Optional[datetime]) -> Optional[datetime]:
         if v is not None and v.year == 1:
             return None
         return v
 
-    @validator("node_spec")
+    @field_validator("node_spec")
     def _validate_node_spec(cls, v: Optional[NodeResources]) -> Optional[NodeResources]:
         if v is not None and not v.to_json():
             return None
@@ -73,6 +74,7 @@ class ClusterUtilization(BaseModel):
     cluster: Cluster
     running_jobs: int
     queued_jobs: int
+    running_preemptible_jobs: int
     nodes: Tuple[NodeUtilization, ...]
 
     @property
@@ -88,4 +90,5 @@ class ClusterSpec(BaseModel):
 
 
 class ClusterPatch(BaseModel):
-    capacity: int
+    capacity: Optional[int] = None
+    allow_preemptible_restriction_exceptions: Optional[bool] = None
