@@ -1,10 +1,10 @@
 from datetime import datetime
 from typing import Dict, List, Optional, Tuple
 
-from pydantic import Field, validator
+from pydantic import Field
 
 from .account import Account
-from .base import BaseModel, IntEnum, StrEnum
+from .base import BaseModel, IntEnum, StrEnum, field_validator
 from .experiment_spec import (
     DataMount,
     EnvVar,
@@ -52,6 +52,7 @@ class CanceledCode(IntEnum):
     system_preemption = 1
     user_preemption = 2
     idle = 3
+    manual_cancellation = 4
 
 
 class JobStatus(BaseModel):
@@ -68,7 +69,7 @@ class JobStatus(BaseModel):
     exit_code: Optional[int] = None
     message: Optional[str] = None
 
-    @validator(
+    @field_validator(
         "created", "scheduled", "started", "exited", "failed", "finalized", "canceled", "idle_since"
     )
     def _validate_datetime(cls, v: Optional[datetime]) -> Optional[datetime]:
@@ -164,12 +165,12 @@ class Job(BaseModel):
     """
 
     id: str
-    name: Optional[str] = None
     kind: JobKind
     author: Account
     workspace: str
-    cluster: Optional[str]
     status: JobStatus
+    name: Optional[str] = None
+    cluster: Optional[str] = None
     execution: Optional[JobExecution] = None
     node: Optional[str] = None
     requests: Optional[JobRequests] = None
@@ -201,6 +202,18 @@ class Job(BaseModel):
             CanceledCode.user_preemption,
         }
 
+    @property
+    def priority(self) -> Optional[Priority]:
+        """
+        Get the priority of the job.
+        """
+        if self.session is not None:
+            return self.session.priority
+        elif self.execution is not None:
+            return self.execution.spec.context.priority
+        else:
+            return None
+
     def check(self):
         """
         :raises JobFailedError: If the job failed or was canceled.
