@@ -98,12 +98,18 @@ class ClusterClient(ServiceClient):
             ).json()
         )
 
-    def update(self, cluster: Union[str, Cluster], max_size: int) -> Cluster:
+    def update(
+        self,
+        cluster: Union[str, Cluster],
+        max_size: Optional[int] = None,
+        allow_preemptible: Optional[bool] = None,
+    ) -> Cluster:
         """
         Modify a cluster.
 
         :param cluster: The cluster ID, full name, or object.
         :param max_size: The maximum number of nodes.
+        :param allow_preemptible: Allow or disallow preemptible jobs.
 
         :raises ClusterNotFound: If the cluster doesn't exist.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
@@ -115,7 +121,9 @@ class ClusterClient(ServiceClient):
             self.request(
                 f"clusters/{cluster_name}",
                 method="PATCH",
-                data=ClusterPatch(capacity=max_size),
+                data=ClusterPatch(
+                    capacity=max_size, allow_preemptible_restriction_exceptions=allow_preemptible
+                ),
                 exceptions_for_status={404: ClusterNotFound(self._not_found_err_msg(cluster))},
             ).json()
         )
@@ -199,13 +207,24 @@ class ClusterClient(ServiceClient):
 
         running_jobs = 0
         queued_jobs = 0
+        running_preemptible_jobs = 0
         node_to_util: Dict[str, Dict[str, Union[int, float]]] = {
-            node.id: {"running_jobs": 0, "gpus_used": 0, "cpus_used": 0.0} for node in nodes
+            node.id: {
+                "running_jobs": 0,
+                "running_preemptible_jobs": 0,
+                "gpus_used": 0,
+                "cpus_used": 0.0,
+            }
+            for node in nodes
         }
 
         for job in self.beaker.job.list(cluster=cluster, finalized=False):
-            if job.status.current == CurrentJobStatus.running:
+            if job.status.current in (CurrentJobStatus.running, CurrentJobStatus.idle):
+                if job.node not in node_to_util:
+                    continue
                 running_jobs += 1
+                if job.priority == Priority.preemptible:
+                    running_preemptible_jobs += 1
             elif job.status.current == CurrentJobStatus.created:
                 queued_jobs += 1
 
@@ -215,6 +234,8 @@ class ClusterClient(ServiceClient):
 
                 node_util = node_to_util[job.node]
                 node_util["running_jobs"] += 1
+                if job.priority == Priority.preemptible:
+                    node_util["running_preemptible_jobs"] += 1
                 if job.requests is not None:
                     if job.requests.gpu_count is not None:
                         node_util["gpus_used"] += job.requests.gpu_count
@@ -225,6 +246,7 @@ class ClusterClient(ServiceClient):
             cluster=cluster,
             running_jobs=running_jobs,
             queued_jobs=queued_jobs,
+            running_preemptible_jobs=running_preemptible_jobs,
             nodes=tuple(
                 [
                     NodeUtilization(
@@ -232,6 +254,9 @@ class ClusterClient(ServiceClient):
                         hostname=node.hostname,
                         limits=node.limits,
                         running_jobs=int(node_to_util[node.id]["running_jobs"]),
+                        running_preemptible_jobs=int(
+                            node_to_util[node.id]["running_preemptible_jobs"]
+                        ),
                         used=NodeResources(
                             gpu_count=None
                             if node.limits.gpu_count is None
@@ -338,6 +363,33 @@ class ClusterClient(ServiceClient):
         cluster_name = self.resolve_cluster(cluster).full_name
         return f"{self.config.agent_address}/cl/{cluster_name}/details"
 
+    def preempt_jobs(self, cluster: Union[str, Cluster]) -> List[Job]:
+        """
+        Preempt all preemptible jobs on the cluster.
+
+        :param cluster: The cluster ID, full name, or object.
+
+        :raises ClusterNotFound: If the cluster doesn't exist.
+        :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
+        :raises RequestException: Any other exception that can occur when contacting the
+            Beaker server.
+        """
+        cluster = self.resolve_cluster(cluster)
+        nodes = set(n.id for n in self.nodes(cluster))
+        current_jobs = self.beaker.job.list(cluster=cluster, finalized=False)
+        preempted_jobs = []
+        for job in current_jobs:
+            if job.node not in nodes:
+                continue
+            if job.execution is None:
+                continue
+            if job.status.current not in {CurrentJobStatus.running, CurrentJobStatus.idle}:
+                continue
+            if job.execution.spec.context.priority != Priority.preemptible:
+                continue
+            preempted_jobs.append(self.beaker.job.preempt(job))
+        return preempted_jobs
+
     def _not_found_err_msg(self, cluster: Union[str, Cluster]) -> str:
         cluster = cluster if isinstance(cluster, str) else cluster.id
         return (
