@@ -123,8 +123,8 @@ class DatasetClient(ServiceClient):
 
         :raises ValueError: If the name is invalid.
         :raises DatasetConflict: If a dataset by that name already exists and ``force=False``.
-        :raises UnexpectedEOFError: If a source file is an empty file, or if a source is a directory and
-            the contents of one of the directory's files changes while creating the dataset.
+        :raises UnexpectedEOFError: If a source is a directory and the contents of one of the directory's files
+            changes while creating the dataset.
         :raises FileNotFoundError: If a source doesn't exist.
         :raises WorkspaceNotSet: If neither ``workspace`` nor
             :data:`Beaker.config.default_workspace <beaker.Config.default_workspace>` are set.
@@ -207,6 +207,7 @@ class DatasetClient(ServiceClient):
         self,
         dataset: Union[str, Dataset],
         target: Optional[PathOrStr] = None,
+        prefix: Optional[str] = None,
         force: bool = False,
         max_workers: Optional[int] = None,
         quiet: bool = False,
@@ -217,7 +218,8 @@ class DatasetClient(ServiceClient):
         Download a dataset.
 
         :param dataset: The dataset ID, name, or object.
-        :param target: The target path to fetched data. Defaults to ``Path(.)``.
+        :param target: The target path to download fetched data to. Defaults to ``Path(.)``.
+        :param prefix: Only download files that start with the given prefix.
         :param max_workers: The maximum number of thread pool workers to use to download files concurrently.
         :param force: If ``True``, existing local files will be overwritten.
         :param quiet: If ``True``, progress won't be displayed.
@@ -271,6 +273,8 @@ class DatasetClient(ServiceClient):
                 download_futures = []
                 try:
                     for file_info in dataset_info.page.data:
+                        if prefix is not None and not file_info.path.startswith(prefix):
+                            continue
                         target_path = target / Path(file_info.path)
                         if not force and target_path.exists():
                             raise FileExistsError(file_info.path)
@@ -518,8 +522,8 @@ class DatasetClient(ServiceClient):
         :raises DatasetNotFound: If the dataset can't be found.
         :raises DatasetWriteError: If the dataset was already committed.
         :raises FileNotFoundError: If a source doesn't exist.
-        :raises UnexpectedEOFError: If a source is an empty file, or if a source is a directory and
-            the contents of one of the directory's files changes while creating the dataset.
+        :raises UnexpectedEOFError: If a source is a directory and the contents of one of the directory's files
+            changes while creating the dataset.
         :raises BeakerError: Any other :class:`~beaker.exceptions.BeakerError` type that can occur.
         :raises RequestException: Any other exception that can occur when contacting the
             Beaker server.
@@ -543,8 +547,6 @@ class DatasetClient(ServiceClient):
                     if target is not None:
                         target_path = Path(str(target)) / target_path
                     size = source.lstat().st_size
-                    if size == 0:
-                        raise UnexpectedEOFError(f"'{source}', empty files are not allowed")
                     path_info[source] = (target_path, size)
                     total_bytes += size
                 elif source.is_dir():
@@ -804,11 +806,11 @@ class DatasetClient(ServiceClient):
                 self.request(
                     f"datasets/{dataset.storage.id}/files/{str(target)}",
                     method="PUT",
-                    data=body,
+                    data=body if size > 0 else b"",
                     token=dataset.storage.token,
                     base_url=dataset.storage.base_url,
                     headers=None if not digest else {self.HEADER_DIGEST: digest},
-                    stream=body is not None,
+                    stream=body is not None and size > 0,
                     exceptions_for_status={
                         403: DatasetWriteError(dataset.id),
                         404: DatasetNotFound(self._not_found_err_msg(dataset.id)),
